@@ -1,5 +1,7 @@
-__version__ = "6.0.0"
-__version_info__ = (6, 0, 0, "", "")
+__version__ = "6.4.0.1"
+__version_info__ = (6, 4, 0.1, "", "")
+__minimum_python_version__ = None
+__maximum_python_version__ = None
 
 # PYSIDE-932: Python 2 cannot import 'zipfile' for embedding while being imported, itself.
 # We simply pre-load all imports for the signature extension.
@@ -22,7 +24,4 @@ import keyword
 import functools
 import typing
 
-from .shiboken6 import *
-
-# Trigger signature initialization via __builtins__.
-_init_pyside_extension()
+from shiboken6.Shiboken import *
